==> koshoten.net-2.1.3.tar.gz: koshoten-net/catalog/includes/modules/kn_payment/cod_table_sagawaex.php <==
<?php
/*
  cod_table_sagawaex.php
  2004/10/1
ǽ

ԡͭ²ҥɥ֥졼
δʿ
ryuhei@secondbrain.co.jp

  Released under the GNU General Public License
*/
// ʧ(sagawaex)
  class cod_table_sagawaex {
    var $code, $title, $description, $enabled;
    var $n_fee, $s_error;
    var $email_footer;

// class constructor
    function cod_table_sagawaex() {
      global $order;

      $this->code = 'cod_table_sagawaex';
      $this->title       = MODULE_PAYMENT_COD_TABLE_SAGAWAEX_TEXT_TITLE;
      $this->description = MODULE_PAYMENT_COD_TABLE_SAGAWAEX_TEXT_DESCRIPTION;
      $this->sort_order  = MODULE_PAYMENT_COD_TABLE_SAGAWAEX_SORT_ORDER;
      $this->enabled = ((MODULE_PAYMENT_COD_TABLE_SAGAWAEX_STATUS == 'True') && ($GLOBALS['shipping']['id'] == 'sagawaex_sagawaex') ? true : false);

      if ((int)MODULE_PAYMENT_COD_TABLE_SAGAWAEX_ORDER_STATUS_ID > 0) {
        $this->order_status = MODULE_PAYMENT_COD_TABLE_SAGAWAEX_ORDER_STATUS_ID;
      }

      if (is_object($order)) $this->update_status();

      $this->email_footer = MODULE_PAYMENT_COD_TABLE_SAGAWAEX_TEXT_EMAIL_FOOTER;
    }

// class methods
    function update_status() {
      global $order;

      if ( ($this->enabled == true) && ((int)MODULE_PAYMENT_COD_TABLE_SAGAWAEX_ZONE > 0) ) {
        $check_flag = false;
        $check_query = tep_db_query("select zone_id from " . TABLE_ZONES_TO_GEO_ZONES . " where geo_zone_id = '" . MODULE_PAYMENT_COD_TABLE_SAGAWAEX_ZONE . "' and zone_country_id = '" . $order->billing['country']['id'] . "' order by zone_id");
        while ($check = tep_db_fetch_array($check_query)) {
          if ($check['zone_id'] < 1) {
            $check_flag = true;
            break;
          } elseif ($check['zone_id'] == $order->billing['zone_id']) {
            $check_flag = true;
            break;
          }
        }

        if ($check_flag == false) {
          $this->enabled = false;
        }
      }
    }

// ׻
    function calc_fee($total_cost) {
      $table_fee = split("[:,]" , MODULE_PAYMENT_COD_TABLE_SAGAWAEX_COST);
      $f_find = false;
      $this->n_fee = 0;
      for ($i = 0; $i < count($table_fee); $i+=2) {
        if ($total_cost <= $table_fee[$i]) {
          $this->n_fee = $table_fee[$i+1];
          $f_find = true;
          break;
        }
      }
      if ( !$f_find ) {
        $this->s_error = MODULE_PAYMENT_COD_TABLE_SAGAWAEX_TEXT_OVERFLOW_ERROR;
      }

      return $f_find;
    }

// class methods
    function javascript_validation() {
      return false;
    }

    function selection() {
      global $currencies;
      global $order;

      $total_cost = $order->info['total'];      // Ƕޤ᤿
      $f_result = $this->calc_fee($total_cost); // 

      $added_hidden = $f_result
          ? tep_draw_hidden_field('codt_fee', $this->n_fee).tep_draw_hidden_field('cod_total_cost', $total_cost)
          : tep_draw_hidden_field('codt_fee_error', $this->s_error);

      $s_message = $f_result
        ? (MODULE_PAYMENT_COD_TABLE_SAGAWAEX_TEXT_FEE . '&nbsp;' . $currencies->format($this->n_fee))
        : ('<font color="#FF0000">' . $this->s_error . '</font>');

      $selection = array(
          'id' => $this->code,
          'module' => $this->title,
          'fields' => array(array('title' => MODULE_PAYMENT_COD_TABLE_SAGAWAEX_TEXT_PROCESS,
                                  'field' => ''),
                            array('title' => $s_message,
                                  'field' => $added_hidden))
      );

      return $selection;
    }

    function pre_confirmation_check() {
      return false;
    }

    function confirmation() {
      global $currencies;
      global $HTTP_POST_VARS;

      $s_result = !$HTTP_POST_VARS['codt_fee_error'];
      $s_message = $s_result
        ? (MODULE_PAYMENT_COD_TABLE_SAGAWAEX_TEXT_FEE . '&nbsp;' . $currencies->format($HTTP_POST_VARS['codt_fee']))
        : ('<font color="#FF0000">' . $HTTP_POST_VARS['codt_fee_error'] . '</font>');

      $confirmation = array(
          'title' => $this->title,
          'fields' => array(array('title' => MODULE_PAYMENT_COD_TABLE_SAGAWAEX_TEXT_PROCESS,
                                  'field' => ''),
                            array('title' => $s_message,
                                  'field' => ''),
                           )
      );
      return $confirmation;
    }

    function process_button() {
      global $currencies;
      global $HTTP_POST_VARS;
      global $order;

      // email_footer ˻Ѥʸ
      $s_message = $HTTP_POST_VARS['codt_fee_error']
        ? $HTTP_POST_VARS['codt_fee_error']
        : sprintf(MODULE_PAYMENT_COD_TABLE_SAGAWAEX_TEXT_MAILFOOTER,
            $currencies->format($order->info['total']),
            $currencies->format($HTTP_POST_VARS['codt_fee']));

      return tep_draw_hidden_field('codt_message', $s_message)
           . tep_draw_hidden_field('codt_fee',$HTTP_POST_VARS['codt_fee']); // for ot_codt
    }

    function before_process() {
      global $HTTP_POST_VARS;

      $this->email_footer = $HTTP_POST_VARS['codt_message'];
    }

    function after_process() {
      return false;
    }

    function get_error() {
      return false;
    }

    function check() {
      if (!isset($this->_check)) {
        $check_query = tep_db_query("select configuration_value from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_PAYMENT_COD_TABLE_SAGAWAEX_STATUS'");
        $this->_check = tep_db_num_rows($check_query);
      }
      return $this->_check;
    }

    function install() {
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('ؤʧͭˤ', 'MODULE_PAYMENT_COD_TABLE_SAGAWAEX_STATUS', 'True', 'ؤˤʧդޤ?', '6', '1', 'tep_cfg_select_option(array(\'True\', \'False\'), ',now());");

      tep_db_query("insert into " . TABLE_CONFIGURATION .
      " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('η׻ɽ', 'MODULE_PAYMENT_COD_TABLE_SAGAWAEX_COST', '9999:315,29999:420,99999:630,299999:1050,499999:2100,999999:3150,9999999:4200', 'ʧۤϢư. : 9999:315,29999:420,99999:630,299999:1050 ... 9999ߤޤ315, 29999ߤޤ420, ...', '6', '2', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('ɽ', 'MODULE_PAYMENT_COD_TABLE_SAGAWAEX_SORT_ORDER', '0', 'ɽǤޤۤɾ̤ɽޤ.', '6', '0' , now())");
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) values ('Ŭϰ', 'MODULE_PAYMENT_COD_TABLE_SAGAWAEX_ZONE', '0', 'Ŭϰ򤹤ȡ򤷤ϰΤߤѲǽȤʤޤ.', '6', '3', 'tep_get_zone_class_title', 'tep_cfg_pull_down_zone_classes(', now())");
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, use_function, date_added) values ('ʸơ', 'MODULE_PAYMENT_COD_TABLE_SAGAWAEX_ORDER_STATUS_ID', '0', 'ꤷơŬѤޤ.', '6', '4', 'tep_cfg_pull_down_order_statuses(', 'tep_get_order_status_name', now())");
    }

    function remove() {
      tep_db_query("delete from " . TABLE_CONFIGURATION . " where configuration_key in ('" . implode("', '", $this->keys()) . "')");
    }

    function keys() {
      return array(
          'MODULE_PAYMENT_COD_TABLE_SAGAWAEX_STATUS',
          'MODULE_PAYMENT_COD_TABLE_SAGAWAEX_COST',
          'MODULE_PAYMENT_COD_TABLE_SAGAWAEX_SORT_ORDER',
          'MODULE_PAYMENT_COD_TABLE_SAGAWAEX_ZONE',
          'MODULE_PAYMENT_COD_TABLE_SAGAWAEX_ORDER_STATUS_ID'
      );
    }
  }
?>

==> koshoten.net-2.1.6.tar.gz: koshoten-net/catalog/includes/modules/kn_payment/cod_table_sagawaex.php <==
<?php
/*
  $Id: cod_table_sagawaex.php,v 1.2 2006/01/29 14:49:24 ryu Exp $

  osCommerce, Open Source E-Commerce Solutions
  http://www.oscommerce.com

  Copyright (c) 2003 osCommerce

  Released under the GNU General Public License

ѹ
2005-02-09 򥻥åѿϢȤ褦
           ʥ֥饦ˤꡢhidden ͤѤʤ뤿ᤳб
*/
// ʧ(sagawaex)
  class cod_table_sagawaex {
    var $code, $title, $description, $enabled;
    var $n_fee, $s_error;
    var $email_footer;

// class constructor
    function cod_table_sagawaex() {
      global $order;

      $this->code = 'cod_table_sagawaex';
      $this->title       = MODULE_PAYMENT_COD_TABLE_SAGAWAEX_TEXT_TITLE;
      $this->description = MODULE_PAYMENT_COD_TABLE_SAGAWAEX_TEXT_DESCRIPTION;
      $this->sort_order  = MODULE_PAYMENT_COD_TABLE_SAGAWAEX_SORT_ORDER;
      $this->enabled = ((MODULE_PAYMENT_COD_TABLE_SAGAWAEX_STATUS == 'True') && ($GLOBALS['shipping']['id'] == 'sagawaex_sagawaex') ? true : false);

      if ((int)MODULE_PAYMENT_COD_TABLE_SAGAWAEX_ORDER_STATUS_ID > 0) {
        $this->order_status = MODULE_PAYMENT_COD_TABLE_SAGAWAEX_ORDER_STATUS_ID;
      }

      if (is_object($order)) $this->update_status();

      $this->email_footer = MODULE_PAYMENT_COD_TABLE_SAGAWAEX_TEXT_EMAIL_FOOTER;
    }

// class methods
    function update_status() {
      global $order;

      if ( ($this->enabled == true) && ((int)MODULE_PAYMENT_COD_TABLE_SAGAWAEX_ZONE > 0) ) {
        $check_flag = false;
        $check_query = tep_db_query("select zone_id from " . TABLE_ZONES_TO_GEO_ZONES . " where geo_zone_id = '" . MODULE_PAYMENT_COD_TABLE_SAGAWAEX_ZONE . "' and zone_country_id = '" . $order->billing['country']['id'] . "' order by zone_id");
        while ($check = tep_db_fetch_array($check_query)) {
          if ($check['zone_id'] < 1) {
            $check_flag = true;
            break;
          } elseif ($check['zone_id'] == $order->billing['zone_id']) {
            $check_flag = true;
            break;
          }
        }

        if ($check_flag == false) {
          $this->enabled = false;
        }
      }
    }

// ׻
    function calc_fee($total_cost) {
      $table_fee = split("[:,]" , MODULE_PAYMENT_COD_TABLE_SAGAWAEX_COST);
      $f_find = false;
      $this->n_fee = 0;
      for ($i = 0; $i < count($table_fee); $i+=2) {
        if ($total_cost <= $table_fee[$i]) {
          $this->n_fee = $table_fee[$i+1];
          $f_find = true;
          break;
        }
      }
      if ( !$f_find ) {
        $this->s_error = MODULE_PAYMENT_COD_TABLE_SAGAWAEX_TEXT_OVERFLOW_ERROR;
      }

      return $f_find;
    }

// class methods
    function javascript_validation() {
      return false;
    }

    function selection() {
      global $currencies;
      global $order;

      $total_cost = $order->info['total'];      // Ƕޤ᤿
      $f_result = $this->calc_fee($total_cost); // 

// 2005-02-09 add -s
      if (!tep_session_is_registered('codt_fee')) tep_session_register('codt_fee');
      $GLOBALS['codt_fee'] = $this->n_fee;
// 2005-02-09 add -e

// 2005-02-09 modi -s
/*
      $added_hidden = $f_result
          ? tep_draw_hidden_field('codt_fee', $this->n_fee).tep_draw_hidden_field('cod_total_cost', $total_cost)
          : tep_draw_hidden_field('codt_fee_error', $this->s_error);
*/
      $added_hidden = $f_result
          ? ''
          : tep_draw_hidden_field('codt_fee_error', $this->s_error);
// 2005-02-09 modi -e

      $s_message = $f_result
        ? (MODULE_PAYMENT_COD_TABLE_SAGAWAEX_TEXT_FEE . '&nbsp;' . $currencies->format($this->n_fee))
        : ('<font color="#FF0000">' . $this->s_error . '</font>');

      $selection = array(
          'id' => $this->code,
          'module' => $this->title,
          'fields' => array(array('title' => MODULE_PAYMENT_COD_TABLE_SAGAWAEX_TEXT_PROCESS,
                                  'field' => ''),
                            array('title' => $s_message,
                                  'field' => $added_hidden))
      );

      return $selection;
    }

    function pre_confirmation_check() {
      return false;
    }

    function confirmation() {
      global $currencies;
      global $HTTP_POST_VARS;

      $s_result = !$HTTP_POST_VARS['codt_fee_error'];
// 2005-02-09 modi -s
/*
      $s_message = $s_result
        ? (MODULE_PAYMENT_COD_TABLE_TEXT_FEE . '&nbsp;' . $currencies->format($HTTP_POST_VARS['codt_fee']))
        : ('<font color="#FF0000">' . $HTTP_POST_VARS['codt_fee_error'] . '</font>');
*/
      $this->get_codt_fee_value();  // $GLOBALS['codt_fee'] 
      $s_message = $s_result
        ? (MODULE_PAYMENT_COD_TABLE_SAGAWAEX_TEXT_FEE . '&nbsp;' . $currencies->format($GLOBALS['codt_fee']))
        : ('<font color="#FF0000">' . $HTTP_POST_VARS['codt_fee_error'] . '</font>');
// 2005-02-09 modi -e

      $confirmation = array(
          'title' => $this->title,
          'fields' => array(array('title' => MODULE_PAYMENT_COD_TABLE_SAGAWAEX_TEXT_PROCESS,
                                  'field' => ''),
                            array('title' => $s_message,
                                  'field' => ''),
                           )
      );
      return $confirmation;
    }

    function process_button() {
      global $currencies;
      global $HTTP_POST_VARS;
      global $order;

      // email_footer ˻Ѥʸ
// 2005-02-09 modi -s
/*
      $s_message = $HTTP_POST_VARS['codt_fee_error']
        ? $HTTP_POST_VARS['codt_fee_error']
        : sprintf(MODULE_PAYMENT_COD_TABLE_TEXT_MAILFOOTER,
            $currencies->format($order->info['total']),
            $currencies->format($HTTP_POST_VARS['codt_fee']));

      return tep_draw_hidden_field('codt_message', htmlspecialchars($s_message))
           . tep_draw_hidden_field('codt_fee',$HTTP_POST_VARS['codt_fee']); // for ot_codt
*/
      $this->get_codt_fee_value();  // $GLOBALS['codt_fee'] 
      $s_message = $HTTP_POST_VARS['codt_fee_error']
        ? $HTTP_POST_VARS['codt_fee_error']
        : sprintf(MODULE_PAYMENT_COD_TABLE_SAGAWAEX_TEXT_MAILFOOTER,
            $currencies->format($order->info['total']),
            $currencies->format($GLOBALS['codt_fee']));

      return tep_draw_hidden_field('codt_message', htmlspecialchars($s_message));
// 2005-02-09 modi -e
    }

    function before_process() {
      global $HTTP_POST_VARS;

      $this->email_footer = str_replace("\r\n","\n",$HTTP_POST_VARS['codt_message']);
    }

    function after_process() {
// 2005-02-09 add -s
      if (tep_session_is_registered('codt_fee')) tep_session_unregister('codt_fee');// 2005-02-09 add -e
      return false;
    }

    function get_error() {
      return false;
    }

    function check() {
      if (!isset($this->_check)) {
        $check_query = tep_db_query("select configuration_value from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_PAYMENT_COD_TABLE_SAGAWAEX_STATUS'");
        $this->_check = tep_db_num_rows($check_query);
      }
      return $this->_check;
    }

    function install() {
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('ؤʧͭˤ', 'MODULE_PAYMENT_COD_TABLE_SAGAWAEX_STATUS', 'True', 'ؤˤʧդޤ?', '6', '1', 'tep_cfg_select_option(array(\'True\', \'False\'), ',now());");

      tep_db_query("insert into " . TABLE_CONFIGURATION .
      " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('η׻ɽ', 'MODULE_PAYMENT_COD_TABLE_SAGAWAEX_COST', '9999:315,29999:420,99999:630,299999:1050,499999:2100,999999:3150,9999999:4200', 'ʧۤϢư. : 9999:315,29999:420,99999:630,299999:1050 ... 9999ߤޤ315, 29999ߤޤ420, ...', '6', '2', now())");

      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('ɽ', 'MODULE_PAYMENT_COD_TABLE_SAGAWAEX_SORT_ORDER', '0', 'ɽǤޤۤɾ̤ɽޤ.', '6', '0' , now())");
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) values ('Ŭϰ', 'MODULE_PAYMENT_COD_TABLE_SAGAWAEX_ZONE', '0', 'Ŭϰ򤹤ȡ򤷤ϰΤߤѲǽȤʤޤ.', '6', '3', 'tep_get_zone_class_title', 'tep_cfg_pull_down_zone_classes(', now())");
      tep_db_query("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, use_function, date_added) values ('ʸơ', 'MODULE_PAYMENT_COD_TABLE_SAGAWAEX_ORDER_STATUS_ID', '0', 'ꤷơŬѤޤ.', '6', '4', 'tep_cfg_pull_down_order_statuses(', 'tep_get_order_status_name', now())");
    }

    function remove() {
      tep_db_query("delete from " . TABLE_CONFIGURATION . " where configuration_key in ('" . implode("', '", $this->keys()) . "')");
    }

    function keys() {
      return array(
          'MODULE_PAYMENT_COD_TABLE_SAGAWAEX_STATUS',
          'MODULE_PAYMENT_COD_TABLE_SAGAWAEX_COST',
          'MODULE_PAYMENT_COD_TABLE_SAGAWAEX_SORT_ORDER',
          'MODULE_PAYMENT_COD_TABLE_SAGAWAEX_ZONE',
          'MODULE_PAYMENT_COD_TABLE_SAGAWAEX_ORDER_STATUS_ID'
      );
    }
// 2005-02-09 add -s
  // -------------------------
  // 
  // -------------------------
    function get_codt_fee() {
      global $order;
      global $total_cost;

      $total_cost = $order->info['total'];      // Ƕޤ᤿
      $f_result = $this->calc_fee($total_cost); // η׻

      return $f_result;
    }

  // -------------------------
  // 'value'֤
  // -------------------------
    function get_codt_fee_value() {
      global $codt_fee;

      if (!tep_session_is_registered('codt_fee')) tep_session_register('codt_fee');

      if (isset($_SESSION['codt_fee'])) {
          $codt_fee = $_SESSION['codt_fee'];
      } elseif (!$codt_fee) {
        $f_result = get_codt_fee();
        $codt_fee = $f_result;
      }
    }
// 2005-02-09 add -e

  }
?>
